@@ -77,7 +77,7 @@ class RayvisionDownload(object):
     def download(self, task_id_list=None,
                  max_speed=None, print_log=True,
                  download_filename_format="true",
-                 local_path=None, custom_server_output_path=None):
+                 local_path=None, server_path=None):
         """Download and update the undownloaded record.
 
         Args:
@@ -94,7 +94,7 @@ class RayvisionDownload(object):
             local_path (str): Download file locally save path,
                 default Window system is "USERPROFILE" environment variable address splicing "renderfarm_sdk",
                 Linux system is "HOME" environment variable address splicing "renderfarm_sdk",
-            custom_server_output_path (str or list): The user customizes the file structure to be downloaded from
+            server_path (str or list): The user customizes the file structure to be downloaded from
                 the output server, and all file structures are downloaded by default,
                 example: "18164087_test/l_layer".
 
@@ -102,13 +102,13 @@ class RayvisionDownload(object):
             bool: True is success.
 
         """
-        self.check_params(task_id_list, custom_server_output_path)
+        self.check_params(task_id_list, server_path)
         local_path = self._check_local_path(local_path)
         self.logger.info("[Rayvision_sync start download .....]")
         self._download_log(task_id_list, local_path)
 
         self._run_download(task_id_list, local_path, max_speed, print_log,
-                          download_filename_format, custom_server_output_path)
+                          download_filename_format, server_path)
         self.logger.info("[Rayvision_sync end download.....]")
         return True
 
@@ -236,8 +236,8 @@ class RayvisionDownload(object):
         return True
 
     def _run_download(self, task_id_list, local_path, max_speed=None,
-                     print_log=True, download_filename_format="true",
-                     custom_server_output_path=None):
+                        print_log=True, download_filename_format="true",
+                        server_path=None):
         """Execute the cmd command for multitasking download.
 
         Args:
@@ -249,7 +249,7 @@ class RayvisionDownload(object):
             download_filename_format: File download local save style,
                 "true": tape task ID and scene name,
                 "false" : download directly without doing processing.
-            custom_server_output_path (str / list): The user customizes the file structure to be downloaded from
+            server_path (str / list): The user customizes the file structure to be downloaded from
                 the output server, and all file structures are downloaded by default,
                 example: "18164087_test/l_layer".
 
@@ -260,16 +260,16 @@ class RayvisionDownload(object):
         #  means 1 GB/S.
         max_speed = max_speed if max_speed is not None else "1048576"
 
-        if not custom_server_output_path:
+        if not server_path:
             task_status_list = self.manage_task.get_task_status(task_id_list)
             output_file_names = (self.manage_task.
                                  output_file_names(task_status_list))
         else:
-            if isinstance(custom_server_output_path, str):
-                output_file_names = [custom_server_output_path]
-            elif isinstance(custom_server_output_path, list):
-                isinstance(custom_server_output_path, list)
-                output_file_names = custom_server_output_path
+            if isinstance(server_path, str):
+                output_file_names = [server_path]
+            elif isinstance(server_path, list):
+                isinstance(server_path, list)
+                output_file_names = server_path
             else:
                 raise Exception("custom_server_output_path must a list or str.")
 
